==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/PeacefulMobEntityLootTableGenerator.java <==
package xen42.peacefulitems;

import java.util.List;
import java.util.concurrent.CompletableFuture;
import java.util.function.BiConsumer;

import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.SimpleFabricLootTableProvider;
import net.minecraft.class_117;
import net.minecraft.class_125;
import net.minecraft.class_1299;
import net.minecraft.class_141;
import net.minecraft.class_165;
import net.minecraft.class_173;
import net.minecraft.class_2040;
import net.minecraft.class_2048;
import net.minecraft.class_215;
import net.minecraft.class_44;
import net.minecraft.class_47;
import net.minecraft.class_52;
import net.minecraft.class_52.class_53;
import net.minecraft.class_5321;
import net.minecraft.class_5341;
import net.minecraft.class_55;
import net.minecraft.class_5662;
import net.minecraft.class_7225;
import net.minecraft.class_7225.class_7874;
import net.minecraft.class_77;

public class PeacefulMobEntityLootTableGenerator extends SimpleFabricLootTableProvider {
    private final CompletableFuture<class_7874> registryLookup;

    protected PeacefulMobEntityLootTableGenerator(FabricDataOutput dataOutput,
            CompletableFuture<class_7874> registryLookup) {
        super(dataOutput, registryLookup, class_173.field_1173);
        this.registryLookup = registryLookup;
    }

    @Override
    public String method_10321() {
        return "PeacefulMobEntityLootTableGenerator";
    }

    @Override
    public void method_10399(class_7225.class_7874 registryLookup, BiConsumer<class_5321<class_52>, class_53> consumer) {
        consumer.accept(
                class_1299.field_6108.method_16351(), 
                class_52.method_324()
                .method_336(
                    class_55.method_347()
                        .method_352(class_44.method_32448(1.0F))
                        .method_351(
                            class_77.method_411(PeacefulModItems.BAT_WING)
                                .method_438(class_141.method_621(class_5662.method_32462(0.0F, 2.0F)))
                                .method_438(class_125.method_547(class_5662.method_32462(0.0F, 1.0F)))
                        )
                )
            );
        consumer.accept(
                PeacefulMod.GHASTLING_ENTITY.method_16351(), 
                class_52.method_324()
                .method_336(
                    class_55.method_347()
                        .method_352(class_44.method_32448(1.0F))
                        .method_351(
                            class_77.method_411(PeacefulModItems.ECTOPLASM)
                                .method_438(class_141.method_621(class_5662.method_32462(0.0F, 2.0F)))
                                .method_438(class_125.method_547(class_5662.method_32462(0.0F, 1.0F)))
                        )
                )
            );
        consumer.accept(
                PeacefulMod.END_CLAM_ENTITY.method_16351(), 
                class_52.method_324()
                .method_336(
                    class_55.method_347()
                        .method_352(class_44.method_32448(1.0F))
                        .method_351(
                            class_77.method_411(PeacefulModItems.CLAM)
                                .method_438(class_141.method_621(class_5662.method_32462(1.0F, 1.0F)))     
                                .method_438((class_117.class_118)class_165.method_724()
                                    .method_524((class_5341.class_210)createSmeltLootCondition()))                           
                        )
                )
            );
    }
    
    protected final class_215.Builder createSmeltLootCondition() {
        return class_215.method_917(class_47.class_50.field_935, class_2048.class_2049.method_8916().method_8919(class_2040.class_2041.method_8897().method_8898(true)));
    }
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/PeacefulMobEntityLootTableGenerator.java <==
package xen42.peacefulitems;

import java.util.concurrent.CompletableFuture;

import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricEntityLootTableProvider;
import net.minecraft.class_117;
import net.minecraft.class_125;
import net.minecraft.class_1299;
import net.minecraft.class_141;
import net.minecraft.class_165;
import net.minecraft.class_44;
import net.minecraft.class_52;
import net.minecraft.class_5341;
import net.minecraft.class_55;
import net.minecraft.class_5662;
import net.minecraft.class_7225.class_7874;
import net.minecraft.class_77;

public class PeacefulMobEntityLootTableGenerator extends FabricEntityLootTableProvider {

    protected PeacefulMobEntityLootTableGenerator(FabricDataOutput dataOutput,
            CompletableFuture<class_7874> registryLookup) {
        super(dataOutput, registryLookup);
    }

    @Override
    public String method_10321() {
        return "PeacefulMobEntityLootTableGenerator";
    }

    @Override
    public void method_10400() {
        this.method_46029(
                class_1299.field_6108, 
                class_52.method_324()
                .method_336(
                    class_55.method_347()
                        .method_352(class_44.method_32448(1.0F))
                        .method_351(
                            class_77.method_411(PeacefulModItems.BAT_WING)
                                .method_438(class_141.method_621(class_5662.method_32462(0.0F, 2.0F)))
                                .method_438(class_125.method_547(field_51846, class_5662.method_32462(0.0F, 1.0F)))
                        )
                )
            );
        this.method_46029(
                PeacefulMod.GHASTLING_ENTITY, 
                class_52.method_324()
                .method_336(
                    class_55.method_347()
                        .method_352(class_44.method_32448(1.0F))
                        .method_351(
                            class_77.method_411(PeacefulModItems.ECTOPLASM)
                                .method_438(class_141.method_621(class_5662.method_32462(0.0F, 2.0F)))
                                .method_438(class_125.method_547(field_51846, class_5662.method_32462(0.0F, 1.0F)))
                        )
                )
            );
        this.method_46029(
                PeacefulMod.END_CLAM_ENTITY, 
                class_52.method_324()
                .method_336(
                    class_55.method_347()
                        .method_352(class_44.method_32448(1.0F))
                        .method_351(
                            class_77.method_411(PeacefulModItems.CLAM)
                                .method_438(class_141.method_621(class_5662.method_32462(1.0F, 1.0F)))     
                                .method_438((class_117.class_118)class_165.method_724()
                                    .method_524((class_5341.class_210)method_60394()))                           
                        )
                )
            );
    }
}
